@@ -1,12 +1,10 @@
-from .types import String , Integer , Boolean , Float , Double , Decimal , Time , Date , Datetime , Uriorcurie , Uri , \
+from linkml_model.types import String , Integer , Boolean , Float , Double , Decimal , Time , Date , Datetime , Uriorcurie , Uri , \
     Ncname , Objectidentifier , Nodeidentifier
-from .extensions import Extension, Extensible
-from .annotations import Annotation, Annotatable
-from .meta import ElementName , SchemaDefinitionName , TypeDefinitionName , SubsetDefinitionName , DefinitionName , \
+from linkml_model.extensions import Extension, Extensible
+from linkml_model.annotations import Annotation, Annotatable
+from linkml_model.meta import ElementName , SchemaDefinitionName , TypeDefinitionName , SubsetDefinitionName , DefinitionName , \
     EnumDefinitionName , SlotDefinitionName , ClassDefinitionName , PrefixPrefixPrefix , LocalNameLocalNameSource , \
     AltDescriptionSource , PermissibleValueText , Element , SchemaDefinition , TypeDefinition , SubsetDefinition , \
     Definition , EnumDefinition , SlotDefinition , ClassDefinition , Prefix , LocalName , Example , AltDescription , \
     PermissibleValue , PvFormulaOptions
 
-# Temporary - remove once migration is complete (?)
-from .meta import YAMLRoot
